@@ -74,8 +74,8 @@ pgf.DEFAULT_FONT_V_CHAR = 308
 
 pgf.STYLE_FILE_BASENAME = "gnuplot-lua-tikz"  -- \usepackage{gnuplot-lua-tikz}
 
-pgf.REVISION = "114"
-pgf.REVISION_DATE = "2020/06/07 19:26:00"
+pgf.REVISION = "120"
+pgf.REVISION_DATE = "2024/10/14 16:17:00"
 
 pgf.styles = {}
 
@@ -931,6 +931,10 @@ f:write([[
   \tikzset{tight background,background rectangle/.style={fill=gpbgfillcolor},show background rectangle}%
 }
 
+% This controls what criterion is used to determine the interior of filled areas.
+% The default is \pgfsetnonzerorule but we request an even/odd test instead.
+\pgfseteorule
+
 % this should reverse the normal text node presets, for the
 % later referencing as described below
 \tikzset{gp refnode/.style={coordinate,yshift=.12ex}}
@@ -1330,8 +1334,16 @@ gfx.format.latex = {
   docheader        = "\\documentclass["..pgf.DEFAULT_FONT_SIZE.."pt]{article}\n"
                       .."\\usepackage[T1]{fontenc}\n"
                       .."\\usepackage{textcomp}\n\n"
-                      .."\\usepackage[utf8x]{inputenc}\n"
-                      .."\\SetUnicodeOption{mathletters}\n\n"
+                      .."\\usepackage{ifluatex,ifxetex}\n"
+                      .."\\ifluatex\n"
+                      .."  \\usepackage{fontspec}\n  \\setmainfont{Free Serif}\n"
+                      .."\\else\\ifxetex\n"
+                      .."  \\usepackage{fontspec}\n  \\setmainfont{FreeSerif}\n"
+                      .."\\else\n"
+                      .."  \\usepackage{ucs}\n"
+                      .."  \\SetUnicodeOption{mathletters}\n"
+                      .."  \\usepackage[utf8x]{inputenc}\n"
+                      .."\\fi\\fi\n\n"
                       .."\\usepackage{"..pgf.STYLE_FILE_BASENAME.."}\n"
                       .."\\pagestyle{empty}\n"
                       .."\\usepackage[active,tightpage]{preview}\n"
@@ -1933,7 +1945,7 @@ term.options = function(opt_str, initial, t_count)
       gfx.opt.full_doc = true
     elseif almost_equals(o_next, "nofull$doc") or almost_equals(o_next, "nostand$alone") then
       -- produce full tex document
-      gfx.opt.full_doc = true
+      gfx.opt.full_doc = false
     elseif almost_equals(o_next, "create$style") then
       -- creates the corresponding LaTeX style from the script
       pgf.create_style()
@@ -1960,7 +1972,7 @@ term.options = function(opt_str, initial, t_count)
       get_next_token()
       if o_type == 'number' then
         fontscale = tonumber(o_next)
-        if fontscale < 0 then
+        if fontscale <= 0 then
           fontscale = 1.0
         end
       else
